@@ -12,22 +12,25 @@ import typer
 from godoo_rpc import import_data
 from godoo_rpc.login import wait_for_odoo
 
-from ...helpers.cli import typer_unpacker
-from .cli import rpc_callback
+from ...cli_common import CommonCLI
 
-app = typer.Typer(callback=rpc_callback, no_args_is_help=True)
+CLI = CommonCLI()
 LOGGER = logging.getLogger(__name__)
 
 
-@typer_unpacker
+@CLI.unpacker
+@CLI.arg_annotator
 def import_to_odoo(
-    ctx: typer.Context,
     read_paths: List[Path] = typer.Argument(
         ...,
         readable=True,
         exists=True,
         help="Folder in which to search for import",
     ),
+    rpc_host=CLI.rpc.rpc_host,
+    rpc_database=CLI.rpc.rpc_db_name,
+    rpc_user=CLI.rpc.rpc_user,
+    rpc_password=CLI.rpc.rpc_password,
     file_regex: str = typer.Option(
         r"(?P<module>.*)\.(csv|py|xlsx|json)$",
         help="Regex for filesearch. Add group 'module' to set a Module for RPC import",
@@ -43,16 +46,14 @@ def import_to_odoo(
     skip_existing_ids: bool = typer.Option(False, help="Will skip import of already existing External IDs."),
 ):
     """
-    Import Csv Files into Odoo.
-    Adds an ir.config_parameter for each imported file,
-    containing the modification time of the file.
-    Will Skip already matching Timestamps and only import files that are new.
+    Import [bold green]csv, xlsx, json, .py [/bold green] files into Odoo.
+    Adds an ir.config_parameter containing timestamp of each imported file.
     """
     odoo_api = wait_for_odoo(
-        odoo_host=ctx.obj.odoo_rpc_host,
-        odoo_db=ctx.obj.odoo_main_db,
-        odoo_user=ctx.obj.odoo_rpc_user,
-        odoo_password=ctx.obj.odoo_rpc_password,
+        odoo_host=rpc_host,
+        odoo_db=rpc_database,
+        odoo_user=rpc_user,
+        odoo_password=rpc_password,
     )
 
     if missing_paths := [p for p in read_paths if not p.exists()]:
